KeyBifEntry

Struct KeyBifEntry 

pub struct KeyBifEntry {
    pub directory: String,
    pub name: String,
    pub recorded_filename: Option<String>,
    pub drives: u16,
    pub bif_oid: Option<String>,
    pub entries: Vec<ResRef>,
}
Specification for a BIF to be written by crate::write_key_and_bif.

Fields

directory: String

Optional directory component to prepend to the emitted BIF path.

name: String

Basename of the emitted BIF, without the .bif suffix.

recorded_filename: Option<String>

Exact filename/path spelling to emit into the KEY file and on disk.

drives: u16

Raw file-table drive flags.

bif_oid: Option<String>

Exact 24-byte BIF OID to emit for E1 outputs.

entries: Vec<ResRef>

Resource entries that should be written into the BIF.